@@ -150,7 +150,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             informacion_global.setAttribute('Año', self.data.get('año'))
             return informacion_global
         except Exception as e:
-            raise Exception("Ocurrio un error al agregar al emisor. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar la información global. Error::: " + str(e))
 
     def get_emisor(self):
         try:
@@ -171,13 +171,13 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             if self.data.get('receptor_residencia_fiscal') != 'MEX':
                 receptor.setAttribute('ResidenciaFiscal', self.data.get('receptor_residencia_fiscal'))
                 receptor.setAttribute('NumRegIdTrib', self.data.get('receptor_num_reg_id_trib'))
-            if self.tipo_comprobante == TRASLADO and self.data.get('uso_cfdi') != 'P01':
-                raise Exception('El campo Uso CFDI debe contener el valor P01 - Por Definir')
+            if self.tipo_comprobante == TRASLADO and self.data.get('uso_cfdi') != 'S01':
+                raise Exception('El campo Uso CFDI debe contener el valor S01 - Sin efectos fiscales.')
             receptor.setAttribute('RegimenFiscalReceptor', self.data.get('regimen_fiscal_receptor'))
             receptor.setAttribute('UsoCFDI', self.data.get('uso_cfdi'))
             return receptor
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar el receptor. Error::: " + str(e))
 
     def get_concepto_fijo(self):
         try:
@@ -202,7 +202,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             conceptos.appendChild(concepto)
             return conceptos
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar el conceptoF. Error::: " + str(e))
 
     def get_impuestos(self):
         try:
@@ -228,7 +228,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
 
             return impuestos
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar los impuestos globales. Error::: " + str(e))
 
     def get_traslados(self, traslado_data):
         traslado = self.dom.createElement('cfdi:Traslado')
@@ -258,7 +258,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 complemento.appendChild(self.get_complemento_cartaporte())
             return complemento
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar los complementos. Error::: " + str(e))
 
     def get_complemento_donatarias(self):
         try:
@@ -275,7 +275,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             donataria.setAttribute('leyenda', self.data.get('donataria_leyenda'))
             return donataria
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar el complemento de Donatarias. Error::: " + str(e))
 
     def get_complemento_pagos(self):
         try:
@@ -339,7 +339,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             pagos.appendChild(pago)
             return pagos
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar el complemento de pago. Error::: " + str(e))
 
     def get_impuestos_documentos_relacionados_pago(self, docto_relacionado):
         impuestos = self.dom.createElement('pago20:ImpuestosDR')
@@ -393,7 +393,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 impuestos_p.appendChild(traslados)
             return impuestos_p
         except Exception as e:
-            raise Exception("Ocurrio un error. Error::: " + str(e))
+            raise Exception("Ocurrio un error al agregar los impuestos en complemento de pago. Error::: " + str(e))
 
     def get_traslados_pago(self, traslado_data):
         traslado = self.dom.createElement('pago20:TrasladoP')
@@ -457,7 +457,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
 
                 conceptos.appendChild(cfdi_concepto)
             except Exception as e:
-                raise Exception("Ocurrio un error. Error::: " + str(e))
+                raise Exception("Ocurrio un error al agregar los conceptos. Error::: " + str(e))
         return conceptos
 
     def get_impuestos_concepto(self,concepto):
@@ -659,8 +659,8 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 cartaporte_operador.setAttribute('TipoFigura', '01')
                 cartaporte_operador.setAttribute('RFCFigura', operador_data.get('RFCOperador'))
                 cartaporte_operador.setAttribute('NumLicencia', operador_data.get('NumLicencia'))
+                cartaporte_figura_transporte.appendChild(cartaporte_operador)
 
-            cartaporte_figura_transporte.appendChild(cartaporte_operador)
             cartaporte.appendChild(cartaporte_figura_transporte)
 
             return cartaporte
